package
Version:
v0.0.0-...-f2e195b
Opens a new window with list of versions in this module.
Published: May 12, 2026
License: MIT
Opens a new window with license information.
Imports: 19
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func DetermineOutputDir(input, appID string) string
-
func ParseInput(input, fileExt string) []string
-
func ProcessFile(inputFile, outputDir, appID string, save bool, workspace bool) error
-
func ScanOnly(dir string, appID string, format string, outputDir string, postman bool)
DetermineOutputDir 确定输出目录
ScanOnly 对已解包目录执行独立敏感信息扫描,生成报告
Source Files
¶
Click to show internal directories.
Click to hide internal directories.